USER STORIES FOR COLLECTIVE.FAQ
===============================

* As reviewer, I can add an FAQ.
* As reviewer, I can add an FAQ item to an FAQ.
* As reviewer, I can add an FAQ item to an FAQ item.
* As reviewer, I can use rich text to create an FAQ item.
* As reviewer, I can link to an existing FAQ item.
* As anonymous user, I can see an FAQ list.
* As anonymous user, I can search the FAQ and FAQ Entry.

Low Priority:

* As anonymous user, I can see just one level of categories.
* As anonymous user, I can toggle all questions to show or hide.
* As anonymous user, I can toggle all categories to show or hide.
* As anonymous user, I can toggle just one question to show or hide.
